@@ -3,4 +3,4 @@ from pydantic import BaseModel
 
 class BaseEventMessage(BaseModel):
     event: str
-    time: int
\ No newline at end of file
+    time: float
\ No newline at end of file
